@@ -107,6 +107,7 @@ class ServiceNameCatalog:
         ServiceName("acm-pca", "ACMPCA"),
         ServiceName("acm", "ACM"),
         ServiceName("alexaforbusiness", "AlexaForBusiness"),
+        ServiceName("amp", "PrometheusService"),
         ServiceName("amplify", "Amplify"),
         ServiceName("amplifybackend", "AmplifyBackend"),
         ServiceName("apigateway", "APIGateway"),
@@ -207,6 +208,7 @@ class ServiceNameCatalog:
         ServiceName("globalaccelerator", "GlobalAccelerator"),
         ServiceName("glue", "Glue"),
         ServiceName("greengrass", "Greengrass"),
+        ServiceName("greengrassv2", "GreengrassV2"),
         ServiceName("groundstation", "GroundStation"),
         ServiceName("guardduty", "GuardDuty"),
         ServiceName("health", "Health"),
@@ -223,11 +225,14 @@ class ServiceNameCatalog:
         ServiceName("iot1click-devices", "IoT1ClickDevicesService"),
         ServiceName("iot1click-projects", "IoT1ClickProjects"),
         ServiceName("iotanalytics", "IoTAnalytics"),
+        ServiceName("iotdeviceadvisor", "IoTDeviceAdvisor"),
         ServiceName("iotevents-data", "IoTEventsData"),
         ServiceName("iotevents", "IoTEvents"),
+        ServiceName("iotfleethub", "IoTFleetHub"),
         ServiceName("iotsecuretunneling", "IoTSecureTunneling"),
         ServiceName("iotsitewise", "IoTSiteWise"),
         ServiceName("iotthingsgraph", "IoTThingsGraph"),
+        ServiceName("iotwireless", "IoTWireless"),
         ServiceName("ivs", "IVS"),
         ServiceName("kafka", "Kafka"),
         ServiceName("kendra", "Kendra"),
@@ -245,6 +250,7 @@ class ServiceNameCatalog:
         ServiceName("lex-runtime", "LexRuntimeService"),
         ServiceName("license-manager", "LicenseManager"),
         ServiceName("lightsail", "Lightsail"),
+        ServiceName("location", "LocationService"),
         ServiceName("logs", "CloudWatchLogs"),
         ServiceName("lookoutvision", "LookoutforVision"),
         ServiceName("machinelearning", "MachineLearning"),
@@ -346,6 +352,7 @@ class ServiceNameCatalog:
         ServiceName("waf-regional", "WAFRegional"),
         ServiceName("waf", "WAF"),
         ServiceName("wafv2", "WAFV2"),
+        ServiceName("wellarchitected", "WellArchitected"),
         ServiceName("workdocs", "WorkDocs"),
         ServiceName("worklink", "WorkLink"),
         ServiceName("workmail", "WorkMail"),
